
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.Scanner;

/**
 * This class takes a sequence of numbers as input and print out a sorted sequence to console.
 *
 * @author Andy Chen
 * @author Benjamin Hoang
 */
public class Problem1 {
    /**
     * BufferedReader is a class that can be connected to a reader class that reads from the console
     *
     * @see Scanner is an alternative way to recieve input but slightly slower
     */
    static BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
    /**
     * PrintWriter is a class that prints to the console.
     * The second parameter is set to true to indicate that it will auto-flush. Auto-flushing will always free the data stored in its stream into the console after certain methods without have to call the .flush() method
     *
     * @see System An alternative to printing to console is System.out.println(). This way is less efficient as it deals with bytes instead of characters
     */
    static PrintWriter pw = new PrintWriter(System.out, true);

    /**
     * This is the main method.
     * It will run the method called run() which contains most of the code for solving the problem.
     * The PrintWriter and BufferReader will be closed after everything is done running.
     * Everything is wrapped in a try catch to catch exceptions throw by BufferedReader and PrintWriter methods, and to catch other errors such as invalid inputs.
     *
     * @param args
     */
    public static void main(String[] args) {
        try{
            run();
            pw.close();
            br.close();
        }catch(IOException IOE){
            pw.println("Error with I/O");
        }catch(NumberFormatException NFE){
            pw.println("Invalid Input");
        }catch(NegativeArraySizeException NAE){
            pw.println("Sequence size can't be negative!");
        }catch(Exception E){
            pw.println("Something went wrong.");
        }
    }

    /**
     * This run() method does all the printing and reading. The code that does the sorting is in another method.
     *
     * @throws IOException IOException is to be caught by the main method. This is thrown by the I/O classes and this exception must be caught in order to use methods from those classes.
     */
    public static void run() throws IOException {
        pw.print("Enter the length of the sequence: ");
        pw.flush();

        int nums = Integer.parseInt(br.readLine());
        int[] arr = new int[nums];
        for(int i = 0;i<nums;i++){
            arr[i] = Integer.parseInt(br.readLine());
        }

        int[] sortedArr = sortSeq(arr);
        pw.print("Ordered Sequence: ");
        pw.flush();
        for(int i = 0;i<sortedArr.length;i++){
            pw.print(sortedArr[i] + " ");
            pw.flush();
        }
    }

    /**
     * This method does the sorting. It uses Arrays.sort() and return the sorted array.
     *
     * @param arr This is the array that is inputted and sorted.
     * @return arr This is the array that is sorted and returned.
     */
    public static int[] sortSeq(int[] arr){
        Arrays.sort(arr);
        return arr;
    }
}
