import java.util.*;
import java.io.*;

/**
 * This class takes a string that represents change and returns the monetary value.
 *
 * @author Andy Chen
 * @author Benjamin Hoang
 */
public class Problem4 {
    /**
     * BufferedReader is a class that can be connected to a reader class that reads from the console
     *
     * @see Scanner is an alternative way to recieve input but slightly slower
     */
    static BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
    /**
     * PrintWriter is a class that prints to the console.
     * The second parameter is set to true to indicate that it will auto-flush. Auto-flushing will always free the data stored in its stream into the console after certain methods without have to call the .flush() method
     *
     * @see System An alternative to printing to console is System.out.println(). This way is less efficient as it deals with bytes instead of characters
     */
    static PrintWriter pw = new PrintWriter(System.out, true);

    /**
     * This is the main method.
     * It will run the method called run() which contains most of the code for solving the problem.
     * The PrintWriter and BufferReader will be closed after everything is done running.
     * Everything is wrapped in a try catch to catch exceptions throw by BufferedReader and PrintWriter methods, and to catch other errors.
     *
     * @param args
     */
    public static void main(String[] args) {
        try{
            run();
            pw.close();
            br.close();
        }catch(IOException IOE){
            pw.println("Error with I/O");
        }catch(Exception E){
            pw.println("Something went wrong.");
        }
    }

    /**
     * This run() method does all the printing and reading. The code that does the money calculation is in another method.
     *
     * @throws IOException IOException is to be caught by the main method. This is thrown by the I/O classes and this exception must be caught in order to use methods from those classes.
     */
    public static void run() throws IOException {
        pw.print("Input the string: ");
        pw.flush();
        String str = br.readLine();
        double total = calculateChange(str);

        pw.printf("The value of the change is: $%.2f", total);
    }

    /**
     * This method takes a string representing change and calculate the total value.
     * @param str The string representing the change.
     * @return The total value of change;
     */
    public static double calculateChange(String str){
        double total = 0;
        for(char c : str.toCharArray()){
            switch (c){
                case 'P':
                    total++;
                    break;
                case 'N':
                    total+=5;
                    break;
                case 'D':
                    total+=10;
                    break;
                case 'Q':
                    total+=25;
                    break;
            }
        }
        total /= 100;
        return total;
    }
}
